@@ -1,7 +1,7 @@
 /*
  *  The ManaPlus Client
  *  Copyright (C) 2010  The Mana Developers
- *  Copyright (C) 2011-2016  The ManaPlus Developers
+ *  Copyright (C) 2011-2017  The ManaPlus Developers
  *
  *  This file is part of The ManaPlus Client.
  *
@@ -128,7 +128,7 @@ bool CompoundSprite::play(const std::string &action)
 bool CompoundSprite::update(const int time)
 {
     bool ret = false;
-    if (!mLastTime)
+    if (A_UNLIKELY(mLastTime == 0))
         mStartTime = time;
     mLastTime = time;
     FOR_EACH (SpriteIterator, it, mSprites)
