@@ -134,6 +134,7 @@
 
 #include "utils/cpu.h"
 #include "utils/delete2.h"
+#include "utils/dumplibs.h"
 #include "utils/env.h"
 #include "utils/fuzzer.h"
 #include "utils/gettext.h"
@@ -207,6 +208,11 @@ namespace
     class AccountListener final : public ActionListener
     {
         public:
+            AccountListener()
+            { }
+
+            A_DELETE_COPY(AccountListener)
+
             void action(const ActionEvent &) override final
             {
                 client->setState(State::CHAR_SELECT);
@@ -216,6 +222,11 @@ namespace
     class LoginListener final : public ActionListener
     {
         public:
+            LoginListener()
+            { }
+
+            A_DELETE_COPY(LoginListener)
+
             void action(const ActionEvent &) override final
             {
                 client->setState(State::PRE_LOGIN);
@@ -340,6 +351,9 @@ void Client::gameInit()
 
     Dirs::initScreenshotDir();
 
+    updateEnv();
+    dumpLibs();
+
     // Initialize SDL
     logger->log1("Initializing SDL...");
     if (SDL_Init(SDL_INIT_VIDEO | SDL_INIT_TIMER) < 0)
@@ -386,7 +400,6 @@ void Client::gameInit()
         // !defined(__native_client__) && !defined(UNITTESTS)
 #endif  // defined(USE_OPENGL)
 
-    updateEnv();
     initGraphics();
 
     touchManager.init();
