@@ -1,6 +1,6 @@
 /*
  *  The ManaPlus Client
- *  Copyright (C) 2012-2016  The ManaPlus Developers
+ *  Copyright (C) 2012-2017  The ManaPlus Developers
  *
  *  This file is part of The ManaPlus Client.
  *
@@ -221,13 +221,6 @@ int GraphicsManager::detectGraphics()
         logger->log("disable OpenGL");
         mode = RENDER_SOFTWARE;
     }
-    else if (findI(mGlRenderer, "LLVM") != std::string::npos)
-    {
-        // llvm opengl emulation
-        logger->log("detected llvm driver");
-        logger->log("disable OpenGL");
-        mode = RENDER_SOFTWARE;
-    }
     else if (findI(mGlVendor, "NVIDIA") != std::string::npos)
     {
         // hope it can work well
