@@ -30,9 +30,12 @@
 class TypeListModel final : public ListModel
 {
     public:
-        TypeListModel()
+        TypeListModel() :
+            ListModel()
         { }
 
+        A_DELETE_COPY(TypeListModel)
+
         /**
          * Used to get number of line in the list
          */
