@@ -295,6 +295,7 @@ void Theme::optionChanged(const std::string &)
 
 struct SkinParameter final
 {
+    A_DEFAULT_COPY(SkinParameter)
     int index;
     std::string name;
 };
@@ -569,9 +570,9 @@ void Theme::fillSkinsList(StringVect &list)
 
 void Theme::fillFontsList(StringVect &list)
 {
-    PHYSFS_permitSymbolicLinks(1);
+    PhysFs::permitLinks(true);
     Files::getFiles(branding.getStringValue("fontsPath"), list);
-    PHYSFS_permitSymbolicLinks(0);
+    PhysFs::permitLinks(false);
 }
 
 void Theme::fillSoundsList(StringVect &list)
