@@ -70,15 +70,20 @@ namespace
 {
     struct MouseOverLink final
     {
-        MouseOverLink(const int x, const int y) :
+        MouseOverLink(const int x,
+                      const int y) :
             mX(x),
             mY(y)
         { }
 
+        A_DEFAULT_COPY(MouseOverLink)
+
         bool operator() (const BrowserLink &link) const
         {
-            return (mX >= link.x1 && mX < link.x2 &&
-                    mY >= link.y1 && mY < link.y2);
+            return (mX >= link.x1 &&
+                mX < link.x2 &&
+                mY >= link.y1 &&
+                mY < link.y2);
         }
         const int mX;
         const int mY;
