@@ -37,7 +37,8 @@
 
 EmulateGuildTab::EmulateGuildTab(const Widget2 *const widget) :
     // TRANSLATORS: guild chat tab name
-    ChatTab(widget, _("Guild"), "", "#Guild", ChatTabType::GUILD)
+    ChatTab(widget, _("Guild"), "", "#Guild", ChatTabType::GUILD),
+    ConfigListener()
 {
     setTabColors(ThemeColorId::GUILD_CHAT_TAB);
     mShowOnline = config.getBoolValue("showGuildOnline");
