@@ -2,7 +2,7 @@
  *  The ManaPlus Client
  *  Copyright (C) 2007  Joshua Langley <joshlangley@optusnet.com.au>
  *  Copyright (C) 2009-2010  The Mana Developers
- *  Copyright (C) 2011-2016  The ManaPlus Developers
+ *  Copyright (C) 2011-2017  The ManaPlus Developers
  *
  *  This file is part of The ManaPlus Client.
  *
@@ -32,14 +32,12 @@ _SDL_stdinc_h
 #ifdef USE_SDL2
 #pragma GCC diagnostic pop
 #endif  // USE_SDL2
-#include <SDL_keyboard.h>
+#include <SDL_events.h>
 
 #include "sdlshared.h"
 
 #include "events/inputevent.h"
 
-union SDL_Event;
-
 class KeyboardConfig final
 {
     public:
@@ -80,9 +78,32 @@ class KeyboardConfig final
         static std::string getKeyShortString(const std::string &key)
                                              A_WARN_UNUSED;
 
-        static SDLKey getKeyFromEvent(const SDL_Event &event) A_WARN_UNUSED;
+        constexpr static SDLKey getKeyFromEvent(const SDL_Event &event)
+                                                A_WARN_UNUSED
+        {
+#ifdef USE_SDL2
+            return event.key.keysym.scancode;
+#else  // USE_SDL2
+
+            return event.key.keysym.sym;
+#endif  // USE_SDL2
+        }
+
+        constexpr2 static int getKeyValueFromEvent(const SDL_Event &event)
+                                                   A_WARN_UNUSED
+        {
+#ifdef USE_SDL2
+            return event.key.keysym.scancode;
+#else  // USE_SDL2
+
+            if (event.key.keysym.sym)
+                return CAST_S32(event.key.keysym.sym);
+            else if (event.key.keysym.scancode > 1)
+                return -event.key.keysym.scancode;
+            return 0;
+#endif  // USE_SDL2
+        }
 
-        static int getKeyValueFromEvent(const SDL_Event &event) A_WARN_UNUSED;
 
         KeysVector *getActionVector(const SDL_Event &event) A_WARN_UNUSED;
 
