@@ -1,6 +1,6 @@
 /*
  *  The ManaPlus Client
- *  Copyright (C) 2013-2016  The ManaPlus Developers
+ *  Copyright (C) 2013-2017  The ManaPlus Developers
  *
  *  This file is part of The ManaPlus Client.
  *
@@ -66,7 +66,6 @@ TEST_CASE("integrity tests", "integrity")
     setEnv("SDL_VIDEODRIVER", "dummy");
 
     client = new Client;
-    PHYSFS_init("manaplus");
     dirSeparator = "/";
     XML::initXML();
     SDL_Init(SDL_INIT_VIDEO);
@@ -163,4 +162,6 @@ TEST_CASE("integrity tests", "integrity")
 
     delete client;
     client = nullptr;
+
+//    PhysFs::deinit();
 }
