@@ -39,6 +39,8 @@
     + __clang_patchlevel__)
 #endif  // __clang__
 
+#define A_DEFAULT_COPY(func)
+
 #if !defined(__GXX_EXPERIMENTAL_CXX0X__)
 #undef nullptr
 #define nullptr 0
@@ -85,8 +87,6 @@
 
 #endif  // GCC_VERSION < 40900
 #endif  // GCC_VERSION < 40700
-#undef Z_NULL
-#define Z_NULL nullptr
 #define M_TCPOK
 #define A_DELETE(func) func = delete
 #define A_DELETE_COPY(name) name(const name &) = delete; \
