@@ -28,6 +28,15 @@
 
 struct Token final
 {
+    Token() :
+        account_ID(BeingId_zero),
+        session_ID1(0),
+        session_ID2(0),
+        sex(Gender::UNSPECIFIED)
+    { }
+
+    A_DELETE_COPY(Token)
+
     BeingId account_ID;
     int session_ID1;
     int session_ID2;
