@@ -30,7 +30,8 @@ extern Net::ServerFeatures *serverFeatures;
 namespace EAthena
 {
 
-ServerFeatures::ServerFeatures()
+ServerFeatures::ServerFeatures() :
+    Net::ServerFeatures()
 {
     serverFeatures = this;
 }
@@ -235,11 +236,6 @@ bool ServerFeatures::haveTeamId() const
     return false;
 }
 
-bool ServerFeatures::haveAdvancedSprites() const
-{
-    return serverVersion >= 7;
-}
-
 bool ServerFeatures::haveExtendedRiding() const
 {
     return serverVersion >= 9;
