@@ -28,7 +28,8 @@ extern Net::ServerFeatures *serverFeatures;
 namespace TmwAthena
 {
 
-ServerFeatures::ServerFeatures()
+ServerFeatures::ServerFeatures() :
+    Net::ServerFeatures()
 {
     serverFeatures = this;
 }
@@ -233,11 +234,6 @@ bool ServerFeatures::haveTeamId() const
     return true;
 }
 
-bool ServerFeatures::haveAdvancedSprites() const
-{
-    return false;
-}
-
 bool ServerFeatures::haveExtendedRiding() const
 {
     return false;
