@@ -2,7 +2,7 @@
  *  The ManaPlus Client
  *  Copyright (C) 2004-2009  The Mana World Development Team
  *  Copyright (C) 2009-2010  The Mana Developers
- *  Copyright (C) 2011-2016  The ManaPlus Developers
+ *  Copyright (C) 2011-2017  The ManaPlus Developers
  *
  *  This file is part of The ManaPlus Client.
  *
@@ -55,11 +55,6 @@ void Animation::addTerminator(const int rand) noexcept2
     addFrame(nullptr, 0, 0, 0, rand);
 }
 
-bool Animation::isTerminator(const Frame &candidate) noexcept2
-{
-    return (!candidate.image && candidate.type == FrameType::ANIMATION);
-}
-
 void Animation::addJump(const std::string &name, const int rand) noexcept2
 {
     Frame frame = { nullptr, 0, 0, 0, rand, FrameType::JUMP, name };
