@@ -27,12 +27,15 @@
 
 struct BeingMenuItem final
 {
-    BeingMenuItem(const std::string &name0, const std::string &command0) :
+    BeingMenuItem(const std::string &name0,
+                  const std::string &command0) :
         name(name0),
         command(command0)
     {
     }
 
+    A_DEFAULT_COPY(BeingMenuItem)
+
     std::string name;
     std::string command;
 };
