@@ -1,6 +1,6 @@
 /*
  *  The ManaPlus Client
- *  Copyright (C) 2013-2016  The ManaPlus Developers
+ *  Copyright (C) 2013-2017  The ManaPlus Developers
  *
  *  This file is part of The ManaPlus Client.
  *
@@ -2354,7 +2354,6 @@ TEST_CASE("Dye real dye")
     setEnv("SDL_VIDEODRIVER", "dummy");
 
     client = new Client;
-    PHYSFS_init("manaplus");
     dirSeparator = "/";
     SDL_Init(SDL_INIT_VIDEO);
     logger = new Logger();
@@ -2392,4 +2391,5 @@ TEST_CASE("Dye real dye")
         dyeCheck("|A:#0000FFFF,FF000050", "arrow_up_A.png");
     }
     delete2(client);
+//    PhysFs::deinit();
 }
