@@ -32,6 +32,11 @@ struct SDL_Surface;
 class ImageWriter final
 {
     public:
+        ImageWriter()
+        { }
+
+        A_DELETE_COPY(ImageWriter)
+
         static bool writePNG(SDL_Surface *const surface,
                              const std::string &filename);
 };
