@@ -35,6 +35,8 @@ namespace
 {
     struct ResourceLoader final
     {
+        A_DEFAULT_COPY(ResourceLoader)
+
         const std::string path;
 
         static Resource *load(const void *const v)
@@ -46,6 +48,7 @@ namespace
             SDL_RWops *const rw = MPHYSFSRWOPS_openRead(rl->path.c_str());
             if (!rw)
             {
+                reportAlways("Physfs error: %s", PhysFs::getLastError());
                 reportAlways("Error loading resource: %s",
                     rl->path.c_str());
                 return nullptr;
