@@ -35,10 +35,16 @@ struct Location final
     /**
      * Constructor.
      */
-    Location(const int px, const int py, MetaTile *const ptile) :
-        x(px), y(py), tile(ptile)
+    Location(const int px,
+             const int py,
+             MetaTile *const ptile) :
+        x(px),
+        y(py),
+        tile(ptile)
     {}
 
+    A_DEFAULT_COPY(Location)
+
     /**
      * Comparison operator.
      */
