@@ -128,9 +128,9 @@ int inflateMemory(unsigned char *restrict const in,
     out = static_cast<unsigned char*>(calloc(bufferSize, 1));
 
     z_stream strm;
-    strm.zalloc = Z_NULL;
-    strm.zfree = Z_NULL;
-    strm.opaque = Z_NULL;
+    strm.zalloc = nullptr;
+    strm.zfree = nullptr;
+    strm.opaque = nullptr;
     strm.next_in = in;
     strm.avail_in = inLength;
     strm.next_out = out;
@@ -1266,6 +1266,8 @@ Map *MapReader::createEmptyMap(const std::string &restrict filename,
         -1);
     map->addLayer(layer);
     map->updateDrawLayersList();
+    map->updateConditionLayers();
+    map->preCacheLayers();
 
     return map;
 }
