@@ -2,7 +2,7 @@
  *  The ManaPlus Client
  *  Copyright (C) 2004-2009  The Mana World Development Team
  *  Copyright (C) 2009-2010  The Mana Developers
- *  Copyright (C) 2011-2016  The ManaPlus Developers
+ *  Copyright (C) 2011-2017  The ManaPlus Developers
  *
  *  This file is part of The ManaPlus Client.
  *
@@ -132,17 +132,9 @@ Image *OpenGLImageHelper::createTextSurface(SDL_Surface *const tmpImage,
 
 int OpenGLImageHelper::powerOfTwo(const int input)
 {
-    int value;
-    if (mTextureType == GL_TEXTURE_2D)
-    {
-        value = 1;
-        while (value < input && value < mTextureSize)
-            value <<= 1;
-    }
-    else
-    {
-        value = input;
-    }
+    int value = 1;
+    while (value < input && value < mTextureSize)
+        value <<= 1;
     return value >= mTextureSize ? mTextureSize : value;
 }
 
