@@ -1,6 +1,6 @@
 /*
  *  The ManaPlus Client
- *  Copyright (C) 2013-2016  The ManaPlus Developers
+ *  Copyright (C) 2013-2017  The ManaPlus Developers
  *
  *  This file is part of The ManaPlus Client.
  *
@@ -88,7 +88,6 @@ TEST_CASE("resourcemanager", "resourcemanager")
     setEnv("SDL_VIDEODRIVER", "dummy");
 
     client = new Client;
-    PHYSFS_init("manaplus");
     dirSeparator = "/";
     XML::initXML();
     SDL_Init(SDL_INIT_VIDEO);
@@ -660,4 +659,5 @@ TEST_CASE("resourcemanager", "resourcemanager")
     resourceManager = safeResman;
     delete client;
     client = nullptr;
+//    PhysFs::deinit();
 }
