@@ -2,7 +2,7 @@
  *  The ManaPlus Client
  *  Copyright (C) 2004-2009  The Mana World Development Team
  *  Copyright (C) 2009-2010  The Mana Developers
- *  Copyright (C) 2011-2016  The ManaPlus Developers
+ *  Copyright (C) 2011-2017  The ManaPlus Developers
  *
  *  This file is part of The ManaPlus Client.
  *
@@ -187,7 +187,7 @@ bool AnimatedSprite::play(const std::string &restrict spriteAction) restrict2
 bool AnimatedSprite::update(const int time) restrict2
 {
     // Avoid freaking out at first frame or when tick_time overflows
-    if (time < mLastTime || mLastTime == 0)
+    if (A_UNLIKELY(time < mLastTime || mLastTime == 0))
         mLastTime = time;
 
     // If not enough time has passed yet, do nothing
@@ -200,7 +200,7 @@ bool AnimatedSprite::update(const int time) restrict2
     const Animation *restrict const animation = mAnimation;
     const Frame *restrict const frame = mFrame;
 
-    if (!updateCurrentAnimation(dt))
+    if (A_UNLIKELY(!updateCurrentAnimation(dt)))
     {
         // Animation finished, reset to default
         play(SpriteAction::STAND);
@@ -434,7 +434,6 @@ const void *AnimatedSprite::getHash() const restrict2
 
 bool AnimatedSprite::updateNumber(const unsigned num) restrict2
 {
-    // TODO need store num in delayed object if it exist for future usage
     if (!mSprite)
         return false;
 
