@@ -2,7 +2,7 @@
  *  The ManaPlus Client
  *  Copyright (C) 2004-2009  The Mana World Development Team
  *  Copyright (C) 2009-2010  The Mana Developers
- *  Copyright (C) 2011-2016  The ManaPlus Developers
+ *  Copyright (C) 2011-2017  The ManaPlus Developers
  *
  *  This file is part of The ManaPlus Client.
  *
@@ -106,7 +106,7 @@ class SoundManager final : public ConfigListener
         void fadeOutAndPlayMusic(const std::string &fileName,
                                  const int ms = 1000);
 
-        static int getMaxVolume() A_WARN_UNUSED
+        constexpr static int getMaxVolume() A_WARN_UNUSED
         { return MIX_MAX_VOLUME; }
 
         void setMusicVolume(const int volume);
