@@ -1,6 +1,6 @@
 /*
  *  The ManaPlus Client
- *  Copyright (C) 2013-2016  The ManaPlus Developers
+ *  Copyright (C) 2013-2017  The ManaPlus Developers
  *
  *  This file is part of The ManaPlus Client.
  *
@@ -31,7 +31,6 @@
 
 TEST_CASE("Files renameFile")
 {
-    PHYSFS_init("manaplus");
     dirSeparator = "/";
     logger = new Logger();
     ResourceManager::init();
@@ -64,11 +63,11 @@ TEST_CASE("Files renameFile")
     delete [] buf;
     delete [] buf2;
     ResourceManager::deleteInstance();
+//    PhysFs::deinit();
 }
 
 TEST_CASE("Files existsLocal")
 {
-    PHYSFS_init("manaplus");
     dirSeparator = "/";
     logger = new Logger();
     ResourceManager::init();
@@ -78,11 +77,11 @@ TEST_CASE("Files existsLocal")
     REQUIRE_FALSE(Files::existsLocal(Files::getPath("help/about1.txt")));
     REQUIRE_FALSE(Files::existsLocal(Files::getPath("help1/about.txt")));
     ResourceManager::deleteInstance();
+//    PhysFs::deinit();
 }
 
 TEST_CASE("Files loadTextFileString")
 {
-    PHYSFS_init("manaplus");
     dirSeparator = "/";
     logger = new Logger();
     ResourceManager::init();
@@ -91,11 +90,11 @@ TEST_CASE("Files loadTextFileString")
     REQUIRE(Files::loadTextFileString("test/simplefile.txt") ==
         "this is test \nfile.");
     ResourceManager::deleteInstance();
+//    PhysFs::deinit();
 }
 
 TEST_CASE("Files loadTextFile")
 {
-    PHYSFS_init("manaplus");
     dirSeparator = "/";
     logger = new Logger();
     ResourceManager::init();
@@ -108,11 +107,11 @@ TEST_CASE("Files loadTextFile")
     REQUIRE(lines[0] == "this is test ");
     REQUIRE(lines[1] == "file.");
     ResourceManager::deleteInstance();
+//    PhysFs::deinit();
 }
 
 TEST_CASE("Files saveTextFile")
 {
-    PHYSFS_init("manaplus");
     dirSeparator = "/";
     logger = new Logger();
     ResourceManager::init();
@@ -126,11 +125,11 @@ TEST_CASE("Files saveTextFile")
     ::remove((dir + "/tempfile.txt").c_str());
     REQUIRE(data == "test line\ntext line2\n");
     ResourceManager::deleteInstance();
+//    PhysFs::deinit();
 }
 
 TEST_CASE("Files getFilesInDir")
 {
-    PHYSFS_init("manaplus");
     dirSeparator = "/";
     logger = new Logger();
     ResourceManager::init();
@@ -155,4 +154,5 @@ TEST_CASE("Files getFilesInDir")
     REQUIRE(list[3] == "perserver/default/features.xml");
     REQUIRE(list[4] == "perserver/default/weapons.xml");
     ResourceManager::deleteInstance();
+//    PhysFs::deinit();
 }
