@@ -33,7 +33,8 @@
 
 struct SDLMemoryObject final
 {
-    SDLMemoryObject(const std::string &name, const char *const file,
+    SDLMemoryObject(const std::string &name,
+                    const char *const file,
                     const unsigned int line) :
         mName(name),
         mAddFile(strprintf("%s:%u", file, line)),
@@ -42,6 +43,8 @@ struct SDLMemoryObject final
     {
     }
 
+    A_DELETE_COPY(SDLMemoryObject)
+
     std::string mName;
     std::string mAddFile;
     std::string mRemoveFile;
