@@ -1,6 +1,6 @@
 /*
  *  The ManaPlus Client
- *  Copyright (C) 2016-2016  The ManaPlus Developers
+ *  Copyright (C) 2016-2017  The ManaPlus Developers
  *
  *  This file is part of The ManaPlus Client.
  *
@@ -21,21 +21,25 @@
 #include "catch.hpp"
 #include "client.h"
 #include "graphicsmanager.h"
-#include "logger.h"
 
 #include "being/actorsprite.h"
 
-#include "utils/translation/podict.h"
-#include "utils/translation/poparser.h"
-
-#include "resources/sdlimagehelper.h"
-
-#include "resources/resourcemanager/resourcemanager.h"
+#include "gui/gui.h"
+#include "gui/theme.h"
 
 #include "utils/delete2.h"
 #include "utils/env.h"
 #include "utils/physfstools.h"
 
+#include "utils/translation/podict.h"
+#include "utils/translation/poparser.h"
+
+#include "render/sdlgraphics.h"
+
+#include "resources/sdlimagehelper.h"
+
+#include "resources/resourcemanager/resourcemanager.h"
+
 #include "debug.h"
 
 TEST_CASE("PoParser tests", "PoParser")
@@ -43,13 +47,13 @@ TEST_CASE("PoParser tests", "PoParser")
     setEnv("SDL_VIDEODRIVER", "dummy");
 
     client = new Client;
-    PHYSFS_init("manaplus");
     dirSeparator = "/";
     logger = new Logger();
     ResourceManager::init();
     resourceManager->addToSearchPath("data", Append_false);
     resourceManager->addToSearchPath("../data", Append_false);
 
+    mainGraphics = new SDLGraphics;
     imageHelper = new SDLImageHelper();
 #ifdef USE_SDL2
     SDLImageHelper::setRenderer(graphicsManager.createRenderer(
@@ -60,7 +64,11 @@ TEST_CASE("PoParser tests", "PoParser")
     graphicsManager.createWindow(640, 480, 0, SDL_ANYFORMAT | SDL_SWSURFACE);
 #endif  // USE_SDL2
 
+    theme = new Theme;
+    Theme::selectSkin();
     ActorSprite::load();
+    gui = new Gui();
+    gui->postInit(mainGraphics);
 
     SECTION("PoParser empty")
     {
@@ -114,4 +122,5 @@ TEST_CASE("PoParser tests", "PoParser")
         delete dict;
     }
     delete2(client);
+//    PhysFs::deinit();
 }
