@@ -1,6 +1,6 @@
 /*
  *  The ManaPlus Client
- *  Copyright (C) 2014-2016  The ManaPlus Developers
+ *  Copyright (C) 2014-2017  The ManaPlus Developers
  *
  *  This file is part of The ManaPlus Client.
  *
@@ -34,7 +34,6 @@
 TEST_CASE("xmlutils readXmlIntVector 1")
 {
     client = new Client;
-    PHYSFS_init("manaplus");
     dirSeparator = "/";
     XML::initXML();
     logger = new Logger();
@@ -59,12 +58,12 @@ TEST_CASE("xmlutils readXmlIntVector 1")
     REQUIRE(1 == arr[3]);
     REQUIRE(1 == arr[4]);
     ResourceManager::deleteInstance();
+//    PhysFs::deinit();
 }
 
 TEST_CASE("xmlutils readXmlStringMap 1")
 {
     client = new Client;
-    PHYSFS_init("manaplus");
     dirSeparator = "/";
     XML::initXML();
     logger = new Logger();
@@ -88,12 +87,12 @@ TEST_CASE("xmlutils readXmlStringMap 1")
     REQUIRE(arr["xD"] == "1");
     REQUIRE(arr["Metal"] == "26");
     ResourceManager::deleteInstance();
+//    PhysFs::deinit();
 }
 
 TEST_CASE("xmlutils readXmlIntMap 1")
 {
     client = new Client;
-    PHYSFS_init("manaplus");
     dirSeparator = "/";
     XML::initXML();
     logger = new Logger();
@@ -117,4 +116,5 @@ TEST_CASE("xmlutils readXmlIntMap 1")
     REQUIRE(arr[10] == 20);
     REQUIRE(arr[3] == 0);
     ResourceManager::deleteInstance();
+//    PhysFs::deinit();
 }
